package main

import androidx.compose.desktop.ui.tooling.preview.Preview
import androidx.compose.material.MaterialTheme
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp
import androidx.compose.ui.window.*
import java.awt.FileDialog
import java.awt.Frame

val customRedColor = Color(0xFFB70D1B)

@Composable
@Preview
fun app() {
    MaterialTheme {
        val currentPage = remember { mutableStateOf("accueil") }

        var glossaryDetail: List<Word> by remember { mutableStateOf(emptyList()) }

        when (currentPage.value) {
            "accueil" -> {
                homePage(
                    onGlossaryClick = { currentPage.value = "glossaire" },
                    onCodeToVerifyClick = { currentPage.value = "choixLangage" }
                )
            }

            "glossaire" -> {
                glossaryPage(
                    onAddWordClick = { currentPage.value = "formulaire" },
                    onImportClick = {
                        selectFile(setOf("csv", "xlsx")) { filePath ->
                            println("Importing file: $filePath")
                            importFile(filePath)
                        }
                    },
                    onExportClick = {
                        val fileDialog = FileDialog(Frame(), "Save as CSV", FileDialog.SAVE)
                        fileDialog.file = "glossaire_exporte.csv" // Initial file name
                        fileDialog.isVisible = true
                        val selectedFile = fileDialog.file
                        val selectedDirectory = fileDialog.directory
                        if (selectedFile != null) {
                            val csvFilePath = "$selectedDirectory$selectedFile"
                            println("Exporting to: $csvFilePath")
                            exportToCSV(csvFilePath)
                        } else {
                            println("Export command cancelled by user.")
                        }
                    },
                    onSeeGlossaryClick = {
                        glossaryDetail = loadDatasFromFile()
                        currentPage.value = "glossaireDetail"
                    },
                    onBackClick = { currentPage.value = "accueil" }
                )
            }
            "glossaireDetail" -> {
                glossaryDetailedPage(
                    glossary = glossaryDetail,
                    onBackClick = { currentPage.value = "glossaire" }
                )
            }

            "formulaire" -> {
                formPage(onCancelClick = { currentPage.value = "glossaire" })
            }

            "choixLangage" -> {
                val pythonExtensions = setOf("py")
                val javaExtensions = setOf("java")
                val jsExtensions = setOf("js", "html")
                choixLangagePage(
                    onBackClick = { currentPage.value = "accueil" },
                    onPythonClick = {
                        selectFile(pythonExtensions) { filePath ->
                            println("Python file selected: $filePath") // Change by parser functions
                        }
                    },
                    onJavaClick = {
                        selectFile(javaExtensions) { filePath ->
                            println("Java file selected: $filePath") // Change by parser functions
                        }
                    },
                    onJavaScriptClick = {
                        selectFile(jsExtensions) { filePath ->
                            mostUsedWordList = parser(filePath) // Change by parser functions
                        }
                    }
                )
            }
            // ... Add other pages here ...
        }
    }
}

fun main() = application {
    val state = rememberWindowState(
        placement = WindowPlacement.Floating,
        position = WindowPosition(Alignment.Center),
        isMinimized = false,
        width = 1280.dp,
        height = 720.dp
    )

    Window(
        title = "Quali'Nomme",
        resizable = true,
        state = state,
        icon = painterResource("assets/logo/logo.png"),
        onCloseRequest = ::exitApplication
    ) {
        app()
    }
}
